Window Example
===============================================================================

:download:`window.enaml <../../../examples/widgets/window.enaml>`

.. literalinclude:: ../../../examples/widgets/window.enaml
    :language: python

::

 $ enaml-run window.enaml

.. image:: images/window.png
